<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns="urn:hl7-org:v3" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xs="http://www.w3.org/2001/XMLSchema">
    <xsl:output method="xml" indent="yes" exclude-result-prefixes="#all" />
    <xsl:strip-space elements="*"/>
    <!-- Transforms MP 9.05 message/CDA into MP 9.06 -->
    <!-- issue 128, nieuwe terminologie codering voor verstrekkingsverzoek. Heeft impact ook op alle aanroepende templateIds -->
    <!-- nieuwe template id voor verstrekkingsverzoek -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9087']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9231'"/>
    </xsl:template>
    <!-- nieuwe code -->
    <xsl:template match="hl7:supply[hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9087' or @root='2.16.840.1.113883.2.4.3.11.60.20.77.10.9131']]/hl7:code">
        <xsl:copy>
            <xsl:apply-templates select="@*"/>
            <xsl:attribute name="code">52711000146108</xsl:attribute>
            <xsl:attribute name="codeSystem">2.16.840.1.113883.6.96</xsl:attribute>
            <xsl:attribute name="codeSystemName">SNOMED CT</xsl:attribute>
        </xsl:copy>
    </xsl:template>
    <!-- medicatiegegevens organizer -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9192']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9221'"/>
    </xsl:template>
    <!-- medicatiegegevens CDA -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9197']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9222'"/>
    </xsl:template>
    <!-- voorschrift organizer -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9126']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9217'"/>
    </xsl:template>
    <!-- voorschrift CDA -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9140']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9219'"/>
    </xsl:template>
    <!-- issue 313, nieuwe SNOMED code voor CDA's die betrekking hebben op medicatie -->
    <xsl:template match="hl7:ClinicalDocument/hl7:code">
        <xsl:copy>
            <xsl:apply-templates select="@*"/>
            <xsl:attribute name="code">52981000146104</xsl:attribute>
            <xsl:attribute name="codeSystem">2.16.840.1.113883.6.96</xsl:attribute>
            <xsl:attribute name="codeSystemName">SNOMED CT</xsl:attribute>
        </xsl:copy>
    </xsl:template>
    <!-- issue 320, 327, 328 - geen wijzigingen in xml instances -->
    <!-- issue 330, nieuwe templateIds voor eigen en andermans bouwstenen: MA, TA, GB. Heeft impact op alle aanroepende templateIds -->
    <!-- medicatieoverzicht organizer -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9193']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9204'"/>
    </xsl:template>
    <!-- medicatieoverzicht CDA -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9199']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9207'"/>
    </xsl:template>
    <!-- sturen gebruik organizer -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9191']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9225'"/>
    </xsl:template>
    <!-- sturen gebruik CDA -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9198']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9227'"/>
    </xsl:template>
    <!-- afhandelen voorschrift organizer -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9124']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9228'"/>
    </xsl:template>
    <!-- afhandelen voorschrift CDA -->
    <!-- issue 333, te vervangen template id bijgewerkt van 9133 naar 9136 -->
    <xsl:template match="hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9136']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9229'"/>
    </xsl:template>
    <!-- eigen MA naar 9216 -->
    <xsl:template match="*[not(hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']])]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9148']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9216'"/>
    </xsl:template>
    <!-- convert kopie ma in template 9148 naar nieuwe template 9202 -->
    <xsl:template match="*[hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']]]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9148']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9202'"/>
    </xsl:template>
    <!-- eigen ta in template 9152 naar nieuwe template 9223 -->
    <xsl:template match="*[not(hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']])]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9152']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9223'"/>
    </xsl:template>
    <!-- convert kopie ta in template 9152 naar nieuwe template 9209 -->
    <xsl:template match="*[hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']]]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9152']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9209'"/>
    </xsl:template>
    <!-- eigen gb in template 9190 naar nieuwe template 9224 -->
    <xsl:template match="*[not(hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']])]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9190']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9224'"/>
    </xsl:template>
    <!-- convert kopie gb in template 9190 naar nieuwe template 9205 -->
    <xsl:template match="*[hl7:entryRelationship[hl7:observation[hl7:code[@code = '16'][@codeSystem = '2.16.840.1.113883.2.4.3.11.60.20.77.5.2']]][hl7:value[@value = 'true']]]/hl7:templateId[@root = '2.16.840.1.113883.2.4.3.11.60.20.77.10.9190']/@root">
        <xsl:attribute name="root" select="'2.16.840.1.113883.2.4.3.11.60.20.77.10.9205'"/>
    </xsl:template>
    <!-- issue 331 - geen wijzigingen in xml instances -->

    <!-- Default copy xsl template -->
    <xsl:template match="@* | node()">
        <xsl:copy>
            <xsl:apply-templates select="@* | node()"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>
